@@ -1,5 +1,6 @@
 import os
 import sys
+import logging
 from pprint import pprint
 from timeit import default_timer as timer
 from datetime import datetime, timedelta
@@ -10,6 +11,8 @@ from mkdocs.plugins import BasePlugin
 
 from github import Github
 
+LOG = logging.getLogger("mkdocs.plugins." + __name__)
+
 class GitCommittersPlugin(BasePlugin):
 
     config_scheme = (
@@ -29,7 +32,7 @@ class GitCommittersPlugin(BasePlugin):
         if 'MKDOCS_GIT_COMMITTERS_APIKEY' in os.environ:
             self.config['token'] = os.environ['MKDOCS_GIT_COMMITTERS_APIKEY']
         if self.config['token'] and self.config['token'] != '':
-            print("INFO    -  git-committers plugin ENABLED")
+            LOG.info("git-committers plugin ENABLED")
             self.enabled = True
             if self.config['enterprise_hostname'] and self.config['enterprise_hostname'] != '':
                 self.github = Github( base_url="https://" + self.config['enterprise_hostname'] + "/api/v3", login_or_token=self.config['token'] )
@@ -38,7 +41,7 @@ class GitCommittersPlugin(BasePlugin):
             self.repo = self.github.get_repo( self.config['repository'] )
             self.branch = self.config['branch']
         else:
-            print("WARNING -  git-committers plugin DISABLED: no git token provided")
+            LOG.warning("git-committers plugin DISABLED: no git token provided")
         return config
 
     def get_last_commit(self, path):
@@ -85,12 +88,18 @@ class GitCommittersPlugin(BasePlugin):
         committers = self.get_committers(git_path)
         if 'contributors' in page.meta:
             users = page.meta['contributors'].split(',')
+            seen = False
             for u in users:
+                for item in committers:
+                    if item['login'] == u:
+                        seen = True
+                if seen:
+                    continue
                 try: 
                     c = self.get_github_user( u )
                     committers.append( c )
                 except:
-                    print("WARNING - could not find github user " + u)
+                    LOG.warning("could not find github user %s",u)
 
         if committers:
             context['committers'] = committers
